@@ -396,7 +396,12 @@ class Instance(Base):
 	def logview(self) -> List[str]:
 		"""Returns the last 2MB of the join.log file"""
 		with open(LOGFILE, 'rb') as fd:
-			return fd.read(2097152).decode('utf-8', 'replace')
+			size = 2097152
+			try:
+				fd.seek(max(os.stat(fd.name).st_size - size, 0))
+			except IOError:
+				pass
+			return fd.read(size).decode('utf-8', 'replace')
 
 	@sanitize(
 		username=StringSanitizer(required=True, minimum=1),
